import pytest


@pytest.fixture()
def tmp_text_file(tmpdir_factory):
    fn = tmpdir_factory.mktemp("data").join("empty.txt")
    fn.write(b'')
    return fn


@pytest.fixture
def no_cover_compat(request):
    """A pytest fixture to disable coverage.

    .. note::

         After the next version of ``pytest-cov`` is released, it will be possible to directly
         use the ``no_cover`` fixture or marker.
    """

    # Check with hasplugin to avoid getplugin exception in older pytest.
    if request.config.pluginmanager.hasplugin('_cov'):
        plugin = request.config.pluginmanager.getplugin('_cov')
        if plugin.cov_controller:
            plugin.cov_controller.cov.stop()
            plugin.cov_controller.unset_env()
            yield plugin.cov_controller
            plugin.cov_controller.set_env()
            plugin.cov_controller.cov.start()



import io
from setuptools import setup
from setuptools.extension import Extension
import versioneer

with io.open('README.md', encoding='utf_8') as fp:
    readme = fp.read()

setup(
    author="Andreas Mueller",
    author_email="t3kcit+wordcloud@gmail.com",
    name='wordcloud',
    version=versioneer.get_version(),
    cmdclass=versioneer.get_cmdclass(),
    url='https://github.com/amueller/word_cloud',
    description='A little word cloud generator',
    long_description=readme,
    long_description_content_type='text/markdown; charset=UTF-8',
    license='MIT',
    install_requires=['numpy>=1.6.1', 'pillow', 'matplotlib'],
    ext_modules=[Extension("wordcloud.query_integral_image",
                           ["wordcloud/query_integral_image.c"])],
    entry_points={'console_scripts': ['wordcloud_cli=wordcloud.__main__:main']},
    packages=['wordcloud'],
    package_data={'wordcloud': ['stopwords', 'DroidSansMono.ttf']}
)
